/// <reference types="backbone" />
import * as Backbone from 'backbone';
import { ManagerBase } from '@jupyter-widgets/base';
import { IDisposable } from '@phosphor/disposable';
import { Widget } from '@phosphor/widgets';
import { IRenderMime } from '@jupyterlab/rendermime';
import { Kernel } from '@jupyterlab/services';
import { DocumentRegistry } from '@jupyterlab/docregistry';
export declare class BackboneViewWrapper extends Widget {
    /**
     * Construct a new `Backbone` wrapper widget.
     *
     * @param view - The `Backbone.View` instance being wrapped.
     */
    constructor(view: Backbone.View<any>);
    onAfterAttach(msg: any): void;
    dispose(): void;
    private _view;
}
/**
 * A widget manager that returns phosphor widgets.
 */
export declare class WidgetManager extends ManagerBase<Widget> implements IDisposable {
    constructor(context: DocumentRegistry.IContext<DocumentRegistry.IModel>, rendermime: IRenderMime);
    newKernel(kernel: Kernel.IKernelConnection): void;
    /**
     * Return a phosphor widget representing the view
     */
    display_view(msg: any, view: Backbone.View<Backbone.Model>, options: any): Promise<Widget>;
    /**
     * Create a comm.
     */
    _create_comm(target_name: string, model_id: string, data?: any): Promise<any>;
    /**
     * Get the currently-registered comms.
     */
    _get_comm_info(): Promise<any>;
    /**
     * Get whether the manager is disposed.
     *
     * #### Notes
     * This is a read-only property.
     */
    readonly isDisposed: boolean;
    /**
     * Dispose the resources held by the manager.
     */
    dispose(): void;
    /**
     * Load a class and return a promise to the loaded object.
     */
    protected loadClass(className: string, moduleName: string, moduleVersion: string): any;
    readonly context: DocumentRegistry.IContext<DocumentRegistry.IModel>;
    readonly rendermime: IRenderMime;
    register(data: WidgetManager.IWidgetData): void;
    private _context;
    private _registry;
    private _rendermime;
    _commRegistration: IDisposable;
}
export declare namespace WidgetManager {
    interface IWidgetData {
        name: string;
        version: string;
        exports: any;
    }
}
