// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var widgets_1 = require("@phosphor/widgets");
/**
 * A renderer for widgets.
 */
var WidgetRenderer = (function () {
    function WidgetRenderer(widgetManager) {
        this.mimeTypes = ['application/vnd.jupyter.widget-view+json'];
        this._manager = widgetManager;
    }
    /**
     * Whether the renderer can render given the render options.
     *
     * @param options - The options that would be used to render the data.
     */
    WidgetRenderer.prototype.canRender = function (options) {
        var source = options.model.data.get(options.mimeType);
        var model = this._manager.get_model(source.model_id);
        return model !== void 0;
    };
    /**
     * Whether the renderer will sanitize the data given the render options.
     */
    WidgetRenderer.prototype.wouldSanitize = function (options) {
        return false;
    };
    /**
     * Render the transformed mime data.
     *
     * @param options - The options used to render the data.
     */
    WidgetRenderer.prototype.render = function (options) {
        var _this = this;
        // data is a model id
        var w = new widgets_1.Panel();
        var source = options.model.data.get(options.mimeType);
        var model = this._manager.get_model(source.model_id);
        if (model) {
            model.then(function (model) {
                return _this._manager.display_model(void 0, model, void 0);
            }).then(function (view) {
                w.addWidget(view);
            });
        }
        else {
            // Model doesn't exist
            var error = document.createElement('p');
            error.textContent = 'Widget not found.';
            w.addWidget(new widgets_1.Widget({ node: error }));
        }
        return w;
    };
    Object.defineProperty(WidgetRenderer.prototype, "isDisposed", {
        /**
         * Get whether the manager is disposed.
         *
         * #### Notes
         * This is a read-only property.
         */
        get: function () {
            return this._manager === null;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Dispose the resources held by the manager.
     */
    WidgetRenderer.prototype.dispose = function () {
        if (this.isDisposed) {
            return;
        }
        this._manager = null;
    };
    return WidgetRenderer;
}());
exports.WidgetRenderer = WidgetRenderer;
